# fast Na module

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

# Translated from Pan 2018 cardiac AP 

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    # load gate transition parameters
    params_K1 = [1.1273394822768654,	0.03356898582323646,	13544.806358561376,	3.115336723982081]

    alpha_K1_bg = params_K1[0] * 1e3 #unit    s ^ -1
    beta_K1_bg = params_K1[2] * 1e3 # unit    s ^ -1

    # constants are stored in V
    F = V['F']
    R = V['R']
    T = V['T']
    N_A = V['N_A']
    cKo = V['cKo']
    G_GHK = 7.792190214146139e-09    # Unit mA/mM
    P_K1 = G_GHK/F * 1e12 # Unit pL/s . G_GHK [=] Amp/(mol/s)
    x_K1_channel = 4261 / N_A * 1e15 # unit    fmol
    x_K1_channel = V['numChannels']/N_A*1e15 # unit fmol

    # Calculate bond graph constants from kinetic parameters
    # Note: units of kappa are fmol/s, units of K are fmol^-1
    kf_K1 = [P_K1/x_K1_channel/np.sqrt(cKo),
            alpha_K1_bg]

    kr_K1 = [P_K1/x_K1_channel/np.sqrt(cKo),
            beta_K1_bg]

    k_kinetic = kf_K1 + kr_K1

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o']] + [1] * (num_rows-2)

    return (k_kinetic, N_cT, K_C, W)













